pub fn run<I, T>(args: I) -> Result<i32, LauncherError>Expand description
Parses arguments and dispatches to built-in commands (add/update/remove/list)
or extension subcommands. This is the entry point for the tempo CLI.
pub fn run<I, T>(args: I) -> Result<i32, LauncherError>Parses arguments and dispatches to built-in commands (add/update/remove/list)
or extension subcommands. This is the entry point for the tempo CLI.